@@ -1,6 +1,6 @@
 #| nokogiri-widgets/font.jl -- font selection widget
 
-   $Id: font.jl.in,v 1.1 2003/08/16 18:35:38 jsh Exp $
+   $Id: font.jl,v 1.4.2.3 2002/05/22 06:55:28 jsh Exp $
 
    Copyright (C) 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -24,20 +24,10 @@
 (define-structure sawfish.gtk.widgets.font ()
 
     (open rep
-	  rep.system
 	  gui.gtk-2.gtk
-	  sawfish.gtk.widget
-	  sawfish.wm.util.font)
+	  sawfish.gtk.widget)
 
-  ;; FIXME: this is broken, in that only if Xrender is present
-  ;; does gdk use Xft. But, it's the best I can do..
-  (define use-xft (let ((x (getenv "GDK_USE_XFT")))
-		    (or (not x) (/= (string->number x) 0))))
-
-  ;; defined by configure
-  (define have-pango-xft (eq 'yes 'yes))
-
-  (define default-font (if use-xft "Sans" "fixed"))
+  (defconst default-font "fixed")
 
   (define (make-font-item changed-callback)
     (let* ((box (gtk-hbox-new nil box-spacing))
@@ -72,31 +62,10 @@
       (lambda (op)
 	(case op
 	  ((set) (lambda (x)
-		   (cond ((stringp x)
-			  (gtk-entry-set-text entry x))
-			 ((consp x)
-			  (let ((face (cond
-					((string-equal (car x) "Xft")
-					 (xft-description->face (cdr x)))
-					((string-equal (car x) "xlfd")
-					 (xlfd-description->face (cdr x)))
-					((string-equal (car x) "pango")
-					 (pango-description->face (cdr x))))))
-			    (when face
-			      (gtk-entry-set-text
-			       entry (face->pango-description face)))))
-			 (t (gtk-entry-set-text entry default-font)))))
+		   (gtk-entry-set-text entry (and (stringp x) x))))
 	  ((clear) (lambda ()
 		     (gtk-entry-set-text entry default-font)))
-	  ((ref) (lambda ()
-		   (let* ((pango-name (gtk-entry-get-text entry))
-			  (face (pango-description->face pango-name)))
-		     (cond ((not face) nil)
-			   (use-xft
-			    (if have-pango-xft
-				(cons "Pango" (face->pango-description face))
-			      (cons "Xft" (face->xft-description face))))
-			   (t (cons "xlfd" (face->xlfd-description face)))))))
+	  ((ref) (lambda () (gtk-entry-get-text entry)))
 	  ((gtk-widget) box)
 	  ((validp) (lambda (x) (stringp x)))))))
 
