@@ -1,6 +1,6 @@
 #| nokogiri-widgets/command.jl
 
-   $Id: command.jl,v 1.9 2003/01/12 20:30:49 jsh Exp $
+   $Id: command.jl,v 1.7.2.4 2002/04/22 06:20:26 jsh Exp $
 
    Copyright (C) 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -102,7 +102,8 @@
 
       (gtk-text-view-set-wrap-mode text-view 'word)
       (gtk-text-view-set-editable text-view nil)
-      (gtk-widget-set-size-request text-view -1 50)
+      ;; XXX fixme
+      ;;(gtk-widget-set-usize text -2 50)
       (gtk-clist-set-selection-mode clist 'browse)
       (gtk-scrolled-window-set-policy scroller 'automatic 'automatic)
       (gtk-scrolled-window-set-policy scroller-2 'automatic 'automatic)
@@ -114,7 +115,8 @@
       (gtk-widget-show-all vbox)
       (unless params-widget
 	(gtk-widget-hide params-hbox))
-      (gtk-widget-set-size-request vbox 350 350)
+      ;; XXX fixme
+      ;;(gtk-widget-set-usize vbox 350 350)
       (update-doc)
 
       (lambda (op)
