@@ -1,6 +1,6 @@
 #| gaol.jl -- protected environment for themes
 
-   $Id: gaol.jl,v 1.35 2002/11/03 04:23:45 jsh Exp $
+   $Id: gaol.jl,v 1.34 2001/01/20 02:40:28 jsh Exp $
 
    Copyright (C) 1999, 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -44,8 +44,8 @@
   ;; safe functions in the core module
   (define safe-functions
     '(get-color-rgb get-color color-name color-rgb colorp get-cursor
-      cursorp get-font get-font-typed font-type-exists-p font-name
-      fontp font-type text-width font-height font-ascent font-descent
+      cursorp get-font font-name fontp text-width font-height
+      font-ascent font-descent
       screen-width screen-height get-x-property get-x-text-property
       list-x-properties x-atom x-atom-name make-image
       make-image-from-x-drawable copy-image
