@@ -1,5 +1,5 @@
 ;; gnome.jl -- minimal GNOME compliance
-;; $Id: gnome.jl,v 1.77 2003/02/20 04:56:05 jsh Exp $
+;; $Id: gnome.jl,v 1.74.2.2 2002/05/07 03:17:14 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -208,17 +208,13 @@
 		     0))))
       (mapc (lambda (state)
 	      (case state
-		((window-list-skip task-list-skip)
-		 (setq hints (logior
-			      (logand
-			       hints (lognot (logior WIN_HINTS_SKIP_WINLIST
-						     WIN_HINTS_SKIP_TASKLIST)))
-			      (if (window-get w 'window-list-skip)
-				  WIN_HINTS_SKIP_WINLIST 0)
-			      (if (window-get w 'task-list-skip)
-				  WIN_HINTS_SKIP_TASKLIST 0)
-			      (if (window-get w 'avoid)
-				  WIN_HINTS_DO_NOT_COVER 0))))))
+		((window-list-skip)
+		 (setq hints (logior (logand
+				      hints (lognot WIN_HINTS_SKIP_WINLIST))
+				     (if (window-get w 'window-list-skip)
+					 WIN_HINTS_SKIP_WINLIST 0)
+				     (if (window-get w 'avoid)
+					 WIN_HINTS_DO_NOT_COVER 0))))))
 	    states)
       (set-x-property w '_WIN_HINTS (vector hints) 'CARDINAL 32)))
 
@@ -268,8 +264,6 @@
 	  (window-put w 'cycle-skip t))
 	(unless (zerop (logand bits WIN_HINTS_SKIP_WINLIST))
 	  (window-put w 'window-list-skip t))
-	(unless (zerop (logand bits WIN_HINTS_SKIP_TASKLIST))
-	  (window-put w 'task-list-skip t))
 	(unless (zerop (logand bits WIN_HINTS_DO_NOT_COVER))
 	  (window-put w 'avoid t)))
       (when layer
@@ -320,9 +314,6 @@
 	     (unless (zerop (logand mask WIN_HINTS_SKIP_WINLIST))
 	       (window-put w 'window-list-skip
 			   (not (zerop (logand bits WIN_HINTS_SKIP_WINLIST)))))
-	     (unless (zerop (logand mask WIN_HINTS_SKIP_TASKLIST))
-	       (window-put w 'task-list-skip
-			   (not (zerop (logand bits WIN_HINTS_SKIP_TASKLIST)))))
 	     (unless (zerop (logand mask WIN_HINTS_DO_NOT_COVER))
 	       (window-put w 'avoid
 			   (not (zerop (logand bits WIN_HINTS_DO_NOT_COVER)))))))
@@ -382,6 +373,7 @@
 	       (proxy-current-event gnome-window-id (lsh 1 19))
 	       t)))))
 
+
 ;;; initialisation
 
   (define (gnome-init)
@@ -428,8 +420,7 @@
     (add-hook 'add-window-hook gnome-set-client-state)
     (call-after-state-changed '(sticky shaded maximized ignored stacking)
 			      gnome-set-client-state)
-    (call-after-state-changed '(window-list-skip task-list-skip)
-			      gnome-set-client-hints)
+    (call-after-state-changed '(window-list-skip) gnome-set-client-hints)
 
     (add-hook 'client-message-hook gnome-client-message-handler)
     (add-hook 'property-notify-hook gnome-property-handler)
@@ -447,4 +438,8 @@
 
   (unless (or gnome-window-id batch-mode)
     (gnome-init)
-    (require 'sawfish.wm.gnome.match-window)))
+    (require 'sawfish.wm.gnome.match-window))
+
+  (add-window-menu-toggle (_ "In GNOME _task list")
+			  'gnome-toggle-skip-tasklist
+			  (lambda (w) (not (gnome-hint-set-p w WIN_HINTS_SKIP_TASKLIST)))))
