@@ -1,6 +1,6 @@
 #| windows.jl -- miscellaneous window mgmt functions
 
-   $Id: windows.jl,v 1.32 2003/03/27 06:30:30 jsh Exp $
+   $Id: windows.jl,v 1.19.2.2 2002/05/07 03:17:06 jsh Exp $
 
    Copyright (C) 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -28,8 +28,6 @@
      (export get-window-by-name
 	     get-window-by-name-re
 	     window-really-wants-input-p
-	     window-transient-p
-	     mark-window-as-transient
 	     desktop-window-p
 	     mark-window-as-desktop
 	     dock-window-p
@@ -39,12 +37,9 @@
 	     warp-cursor-to-window
 	     activate-window
 	     constrain-dimension-to-hints
-	     constrain-aspect-to-hints
 	     resize-window-with-hints
 	     resize-window-with-hints*
 	     window-gravity
-	     adjust-position-for-gravity/x
-	     adjust-position-for-gravity/y
 	     adjust-position-for-gravity
 	     get-window-wm-protocols
 	     window-supports-wm-protocol-p
@@ -90,19 +85,10 @@ means outside the left window edge.")
   (defvar dock-window-properties
     '(window-list-skip cycle-skip fixed-position focus-click-through
       avoid no-history never-iconify never-maximize sticky
-      sticky-viewport placed)
+      stick-viewport placed)
     "List of properties set (to true) on windows marked as docks.")
 
-  (defvar desktop-window-properties
-    '(fixed-position sticky sticky-viewport)
-    "List of properties set (to true) on windows marked as desktops.")
-
-  (defvar desktop-window-depth -4
-    "The stacking depth of desktop windows.")
-
-  (defvar dock-window-depth 0
-    "The stacking depth of dock windows.")
-
+
 ;;; finding windows, reading properties
 
   (define (get-window-by-name name)
@@ -124,36 +110,14 @@ Returns nil if no such window is found."
 	     (window-get w 'ignore-window-input-hint)
 	     (window-wants-input-p w))))
 
-  (define (window-transient-p w)
-    "Return non-nil if WINDOW is a transient window. The returned value will
-then be the numeric id of its parent window."
-    (or (window-get w 'transient-for)
-	(let ((prop (get-x-property w 'WM_TRANSIENT_FOR)))
-	  (when (and prop (eq (car prop) 'WINDOW)
-		     (eql (cadr prop) 32) (>= (length (caddr prop)) 1))
-	    (aref (caddr prop) 0)))))
-
-  (define (mark-window-as-transient w)
-    "Mark that window W is a dialog window of some sort."
-    (require 'sawfish.wm.frames)
-    (unless (window-transient-p w)
-      (window-put w 'transient-for (root-window-id)))
-    (set-window-type w 'transient))
-
   (define (desktop-window-p arg)
     "Return true if ARG represents a desktop window."
     (or (eq arg 'root) (and (windowp arg) (window-get arg 'desktop))))
 
   (define (mark-window-as-desktop w)
     "Mark that the window associated with object W is a desktop window."
-    (require 'sawfish.wm.stacking)
-    (require 'sawfish.wm.frames)
     (window-put w 'desktop t)
-    (window-put w 'keymap root-window-keymap)
-    (mapc (lambda (p)
-	    (window-put w p t)) desktop-window-properties)
-    (set-window-type w 'unframed)
-    (set-window-depth w desktop-window-depth))
+    (window-put w 'keymap root-window-keymap))
 
   (define (focus-desktop)
     "Transfer input focus to the desktop window (if one exists)."
@@ -169,12 +133,8 @@ then be the numeric id of its parent window."
 
   (define (mark-window-as-dock w)
     "Mark that the window associated with object W is a dock window."
-    (require 'sawfish.wm.stacking)
-    (require 'sawfish.wm.frames)
     (window-put w 'dock-type t)
-    (mapc (lambda (p)
-	    (window-put w p t)) dock-window-properties)
-    (set-window-depth w dock-window-depth))
+    (mapc (lambda (p) (window-put w p t)) dock-window-properties))
 
   (define (window-in-cycle-p w #!key ignore-cycle-skip)
     "Returns true if the window W should be included when cycling between
@@ -201,7 +161,7 @@ supported by client window W."
 	     (nreverse out))))))
 
   (define (window-supports-wm-protocol-p w atom)
-    "Return true if window W includes ATOM in its `WM_PROTOCOLS' property."
+    "Return true if winow W includes ATOM in its `WM_PROTOCOLS' property."
     (let* ((prop (get-x-property w 'WM_PROTOCOLS))
 	   (data (and prop (eq (car prop) 'ATOM) (nth 2 prop))))
       (when data
@@ -210,6 +170,7 @@ supported by client window W."
 		((eq (aref data i) atom) t)
 		(t (loop (1+ i))))))))
 
+
 ;;; warping
 
   (define (warp-cursor-to-window w #!optional x y)
@@ -243,9 +204,9 @@ specified by the user."
     (when (window-really-wants-input-p w)
       (set-input-focus w))
     (warp-pointer-if-necessary w)
-    (window-order-push w)
-    (call-window-hook 'activate-window-hook w))
+    (window-order-push w))
 
+
 ;;; resizing windows in accordance with their size hints
 
   (define (constrain-dimension-to-hints x dimension hints)
@@ -263,13 +224,6 @@ specified by the user."
 		   (+ (* (ceiling (/ (- x bottom) inc)) inc) bottom)))))
       (clamp x (or minimum base 1) maximum)))
 
-  (define (constrain-aspect-to-hints a old-b dimension min-aspect max-aspect)
-    (let ((min-ratio (/ (cadr min-aspect) (cddr min-aspect)))
-          (max-ratio (/ (cadr max-aspect) (cddr min-aspect))))
-      (if (eq dimension 'y)
-          (clamp old-b (floor (* a min-ratio)) (floor (* a max-ratio)))
-        (clamp old-b (floor (/ a max-ratio)) (floor (/ a min-ratio))))))
-
   (define (resize-window-with-hints w cols rows #!optional hints)
     "Resize window W to COLS x ROWS, using the window's size hints to define
 the row and column size, and the minimum possible size.
@@ -307,50 +261,47 @@ If HINTS is non-nil, then it is the size hints structure to use. Otherwise
 	;; default gravity is NorthWest (from ICCCM)
 	'north-west))
 
-  (define (adjust-position-for-gravity/x w grav x #!key inverse)
-    (let* ((tl-off (car (window-frame-offset w)))
-	   (br-off (- (car (window-frame-dimensions w))
-		      (car (window-dimensions w))))
-	   (sign (if inverse -1 +1)))
-      (cond ((eq grav 'static)
-	     ;; static gravity is relative to the original
-	     ;; client window position
-	     (+ x (* sign tl-off)))
-	    ((memq grav '(east south-east north-east))
-	     ;; relative to the right of the frame
-	     (- x (* sign (+ br-off (* -2 (window-border-width w))))))
-	    ((memq grav '(north center south))
-	     ;; relative to the horizontal center of the frame
-	     (- x (* sign (quotient
-			   (+ br-off (* -2 (window-border-width w))) 2))))
-	    (t x))))
-
-  (define (adjust-position-for-gravity/y w grav y #!key inverse)
-    (let* ((tl-off (cdr (window-frame-offset w)))
-	   (br-off (- (cdr (window-frame-dimensions w))
-		      (cdr (window-dimensions w))))
-	   (sign (if inverse -1 +1)))
-      (cond ((eq grav 'static)
-	     ;; static gravity is relative to the original
-	     ;; client window position
-	     (+ y (* sign tl-off)))
-	    ((memq grav '(south south-east south-west))
-	     ;; relative to the bottom of the frame
-	     (- y (* sign (+ br-off (* -2 (window-border-width w))))))
-	    ((memq grav '(east center west))
-	     ;; relative to the vertical center of the frame
-	     (- y (* sign (quotient
-			   (+ br-off (* -2 (window-border-width w))) 2))))
-	    (t y))))
-
   ;; UNADJUST means to reverse the gravity compensation, suitable for
   ;; when unmanaging windows at shutdown
   (define (adjust-position-for-gravity w grav coords #!optional unadjust)
-    (cons (adjust-position-for-gravity/x
-	   w grav (car coords) #:inverse unadjust)
-	  (adjust-position-for-gravity/y
-	   w grav (cdr coords) #:inverse unadjust)))
+    (let* ((tl-off (window-frame-offset w))
+	   (br-off (let ((w-dims (window-dimensions w))
+			 (f-dims (window-frame-dimensions w)))
+		     (cons (- (car f-dims) (car w-dims))
+			   (- (cdr f-dims) (cdr w-dims)))))
+	   (sign (if unadjust -1 +1)))
+      (setq coords (cons (car coords) (cdr coords)))
+      (if (eq grav 'static)
+	  (progn
+	    ;; static gravity is relative to the original
+	    ;; client window position
+	    (rplaca coords (+ (car coords) (* sign (car tl-off))))
+	    (rplacd coords (+ (cdr coords) (* sign (cdr tl-off)))))
+	(when (memq grav '(east south-east north-east))
+	  ;; relative to the right of the frame
+	  (rplaca coords (- (car coords)
+			    (* sign (+ (car br-off)
+				       (* -2 (window-border-width w)))))))
+	(when (memq grav '(north center south))
+	  ;; relative to the horizontal center of the frame
+	  (rplaca coords (- (car coords)
+			    (* sign (quotient (+ (car br-off)
+				                 (* -2 (window-border-width w)))
+                                              2)))))
+	(when (memq grav '(south south-east south-west))
+	  ;; relative to the bottom of the frame
+	  (rplacd coords (- (cdr coords)
+			    (* sign (+ (cdr br-off)
+				       (* -2 (window-border-width w)))))))
+	(when (memq grav '(east center west))
+	  ;; relative to the vertical center of the frame
+	  (rplacd coords (- (cdr coords)
+			    (* sign (quotient (+ (cdr br-off)
+				                 (* -2 (window-border-width w)))
+                            	              2))))))
+      coords))
 
+
 ;;; deleting windows
 
   (define (delete-window w #!optional safely)
@@ -370,6 +321,7 @@ If HINTS is non-nil, then it is the size hints structure to use. Otherwise
 
   (define-command 'delete-window-safely delete-window-safely #:spec "%W")
 
+
 ;;; making window names unique
 
   (define (uniquify-name in existing)
@@ -393,6 +345,7 @@ string `uniquify-name-format' to generate unique names."
 
   (define-command 'uniquify-window-name uniquify-window-name #:spec "%W")
 
+
 ;; selecting a single window
 
   (define select-window-map
@@ -411,6 +364,7 @@ string `uniquify-name-format' to generate unique names."
 	      (recursive-edit)))
 	(ungrab-pointer))))
 
+
 ;;; avoided (i.e. non-overlapped) windows
 
   (define (window-avoided-p w)
@@ -430,6 +384,7 @@ returned in the list."
 		      (and (not (eq w window))
 			   (window-avoided-p w)))))
 
+
 ;;; property and window-state changed interface
 
   (define prop-changes '())
@@ -437,24 +392,10 @@ returned in the list."
   (define (call-after-property-changed prop fun)
     "Arrange for function FUN to be called with arguments (WINDOW PROPERTY
 STATE) when the X11 property named PROP (a symbol) changes. PROP may also
-be a list of property names to monitor.
-
-Kluge: if PROP is `WM_NAME', it is replaced with `(WM_NAME _NET_WM_NAME)'.
-This is done to cope with themes that want to update title bars on name
-changes but only watch `WM_NAME'.  A warning is printed on stderr when
-this substitution occurs.  Those themes should really be fixed."
-    (setq prop-changes
-          (cons
-           (cons (cond ((listp prop) prop)
-                       ((eq prop 'WM_NAME)
-                        (format standard-error
-"(call-after-property-changed 'WM_NAME ...) should probably be
-(call-after-property-changed '(WM_NAME _NET_WM_NAME) ...);
-use '(WM_NAME) if you really want only WM_NAME\n")
-                        '(WM_NAME _NET_WM_NAME))
-                       (t (list prop)))
-                 fun)
-           prop-changes)))
+be a list of property names to monitor."
+    (setq prop-changes (cons (cons (if (listp prop)
+				       prop
+				     (list prop)) fun) prop-changes)))
   
   (add-hook 'property-notify-hook
 	    (lambda (w prop state)
@@ -484,6 +425,7 @@ STATES has been changed. STATES may also be a single symbol."
 		 ((cdr cell) w relevant))))
 	    state-changes)))
 
+
 ;; gaollable functions
 
   (gaol-add window-really-wants-input-p window-class window-avoided-p
