@@ -1,5 +1,5 @@
 /* colors.c -- Colour handling
-   $Id: colors.c 4301 2008-11-19 20:45:08Z chrisb $
+   $Id: colors.c,v 1.22 2001/04/23 06:20:49 jsh Exp $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -27,18 +27,15 @@ int color_type;
 DEFSYM(default_foreground, "default-foreground");
 
 DEFUN("get-color-rgb", Fget_color_rgb, Sget_color_rgb,
-      (repv red, repv green, repv blue, repv alpha), rep_Subr4) /*
+      (repv red, repv green, repv blue), rep_Subr3) /*
 ::doc:sawfish.wm.colors#get-color-rgb::
-get-color-rgb RED GREEN BLUE [ALPHA]
+get-color-rgb RED GREEN BLUE
 ::end:: */
 {
     Lisp_Color *f;
-
     rep_DECLARE1(red, rep_INTP);
     rep_DECLARE2(green, rep_INTP);
     rep_DECLARE3(blue, rep_INTP);
-    if (!rep_INTP (alpha))
-	alpha = rep_MAKE_INT (65535);
 
     if (dpy == 0)
 	return Qnil;
@@ -48,8 +45,7 @@ get-color-rgb RED GREEN BLUE [ALPHA]
     {
 	if (f->red == rep_INT(red)
 	    && f->green == rep_INT(green)
-	    && f->blue == rep_INT(blue)
-	    && f->alpha == rep_INT(alpha))
+	    && f->blue == rep_INT(blue))
 	{
 	    break;
 	}
@@ -70,15 +66,14 @@ get-color-rgb RED GREEN BLUE [ALPHA]
 	f->red = rep_INT(red);
 	f->green = rep_INT(green);
 	f->blue = rep_INT(blue);
-	f->alpha = rep_INT(alpha);
 	f->pixel = pixel;
     }
     return rep_VAL(f);
 }
     
-DEFUN("get-color", Fget_color, Sget_color, (repv name, repv alpha), rep_Subr2) /*
+DEFUN("get-color", Fget_color, Sget_color, (repv name), rep_Subr1) /*
 ::doc:sawfish.wm.colors#get-color::
-get-color NAME [ALPHA]
+get-color NAME
 
 Return the color object representing the color named NAME, a standard
 X11 color specifier.
@@ -94,8 +89,7 @@ X11 color specifier.
     {
 	return Fget_color_rgb (rep_MAKE_INT(exact_col.red),
 			       rep_MAKE_INT(exact_col.green),
-			       rep_MAKE_INT(exact_col.blue),
-			       alpha);
+			       rep_MAKE_INT(exact_col.blue));
     }
     else
     {
@@ -123,32 +117,30 @@ DEFUN("color-rgb", Fcolor_rgb, Scolor_rgb, (repv color), rep_Subr1) /*
 ::doc:sawfish.wm.colors#color-rgb::
 color-rgb COLOR
 
-Returns a list of integers (RED GREEN BLUE ALPHA) representing the
-actual color values of the color represented by object COLOR. The
-individual values range from zero to 65535.
+Returns a list of integers (RED GREEN BLUE) representing the actual
+color values of the color represented by object COLOR. The individual
+values range from zero to 65535.
 ::end:: */
 {
     rep_DECLARE1(color, COLORP);
-    return rep_list_4 (rep_MAKE_INT(VCOLOR(color)->red),
+    return rep_list_3 (rep_MAKE_INT(VCOLOR(color)->red),
 		       rep_MAKE_INT(VCOLOR(color)->green),
-		       rep_MAKE_INT(VCOLOR(color)->blue),
-		       rep_MAKE_INT(VCOLOR(color)->alpha));
+		       rep_MAKE_INT(VCOLOR(color)->blue));
 }
 
 DEFUN("color-rgb-8", Fcolor_rgb_8, Scolor_rgb_8, (repv color), rep_Subr1) /*
 ::doc:sawfish.wm.colors#color-rgb::
 color-rgb-8 COLOR
 
-Returns a list of integers (RED GREEN BLUE ALPHA) representing the
-actual color values of the color represented by object COLOR. The
-individual values range from zero to 255.
+Returns a list of integers (RED GREEN BLUE) representing the actual
+color values of the color represented by object COLOR. The individual
+values range from zero to 255.
 ::end:: */
 {
     rep_DECLARE1(color, COLORP);
-    return rep_list_4 (rep_MAKE_INT(VCOLOR(color)->red / 256),
+    return rep_list_3 (rep_MAKE_INT(VCOLOR(color)->red / 256),
 		       rep_MAKE_INT(VCOLOR(color)->green / 256),
-		       rep_MAKE_INT(VCOLOR(color)->blue / 256),
-		       rep_MAKE_INT(VCOLOR(color)->alpha / 256));
+		       rep_MAKE_INT(VCOLOR(color)->blue / 256));
 }
 
 DEFUN("colorp", Fcolorp, Scolorp, (repv win), rep_Subr1) /*
@@ -161,6 +153,7 @@ Returns t if ARG is a color object.
     return COLORP(win) ? Qt : Qnil;
 }
 
+
 /* type hooks */
 
 static int
@@ -198,6 +191,7 @@ color_sweep (void)
     }
 }
 
+
 /* initialisation */
 
 void
@@ -216,8 +210,7 @@ colors_init (void)
     rep_INTERN_SPECIAL(default_foreground);
     if (!batch_mode_p ())
     {
-	DEFSTRING (name, "#000000");
-	repv black = Fget_color (rep_VAL (&name), Qnil);
+	repv black = Fget_color (rep_string_dup("#000000"));
 	if (black == rep_NULL)
 	    black = Qnil;
 	Fset (Qdefault_foreground, black);
