@@ -1,5 +1,5 @@
 /* gradient.c -- draw Afterstep-like gradients in images
-   $Id: gradient.c 4301 2008-11-19 20:45:08Z chrisb $ 
+   $Id: gradient.c,v 1.6 2000/07/27 14:37:56 john Exp $ 
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -24,10 +24,10 @@
 DEFUN("draw-vertical-gradient", Fdraw_vertical_gradient,
       Sdraw_vertical_gradient, (repv img, repv from_, repv to_), rep_Subr3)
 {
-    unsigned char from[3], to[3];
+    u_char from[3], to[3];
     int width, height, stride, channels;
     int x, y;
-    unsigned char *data;
+    u_char *data;
 
     rep_DECLARE1(img, IMAGEP);
     rep_DECLARE2(from_, COLORP);
@@ -66,10 +66,10 @@ DEFUN("draw-vertical-gradient", Fdraw_vertical_gradient,
 DEFUN("draw-horizontal-gradient", Fdraw_horizontal_gradient,
       Sdraw_horizontal_gradient, (repv img, repv from_, repv to_), rep_Subr3)
 {
-    unsigned char from[3], to[3];
+    u_char from[3], to[3];
     int width, height, stride, channels;
     int x, y;
-    unsigned char *data;
+    u_char *data;
 
     rep_DECLARE1(img, IMAGEP);
     rep_DECLARE2(from_, COLORP);
@@ -111,7 +111,7 @@ DEFUN("draw-diagonal-gradient", Fdraw_diagonal_gradient,
     double from[3], to[3];
     int width, height, stride, channels;
     int x, y;
-    unsigned char *data;
+    u_char *data;
 
     rep_DECLARE1(img, IMAGEP);
     rep_DECLARE2(from_, COLORP);
@@ -156,6 +156,7 @@ DEFUN("draw-diagonal-gradient", Fdraw_diagonal_gradient,
     return img;
 }
 
+
 /* DL hooks */
 
 repv
