@@ -1,5 +1,5 @@
 /* keys.c -- Key binding and evaluating (this should be called events.c)
-   $Id: keys.c 4301 2008-11-19 20:45:08Z chrisb $
+   $Id: keys.c,v 1.84.2.1 2002/04/22 06:20:42 jsh Exp $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -32,7 +32,7 @@
 
 /* current_event holds the event we're processing (or 0s), last_event
    contains the previously processed event.  */
-static unsigned long current_event[2], last_event[2];
+static u_long current_event[2], last_event[2];
 
 /* print_prefix means echo all events upto the end of the key-sequence.
    printed_this_prefix says the last event has been echoed. */
@@ -40,12 +40,12 @@ static bool print_prefix, printed_this_prefix;
 
 /* Buffer holding the events making this key-sequence. */
 #define EVENT_BUFSIZ 20
-static unsigned long event_buf[EVENT_BUFSIZ]; /* one event = (code,mods) */
+static u_long event_buf[EVENT_BUFSIZ]; /* one event = (code,mods) */
 static int event_index;
 
 /* Data for testing double-clicks */
 static Time last_click;
-static unsigned long last_click_button;
+static u_long last_click_button;
 static int click_count;
 
 /* These control which types of keyboard events we actually evaluate */
@@ -80,14 +80,14 @@ static repv next_keymap_path;
 DEFSYM(multi_click_delay, "multi-click-delay");
 
 /* The X modifiers being used for Meta, Alt, and Hyper */
-static unsigned long meta_mod, alt_mod, hyper_mod, super_mod;
+static u_long meta_mod, alt_mod, hyper_mod, super_mod;
 
 /* The user-customizable modifier; used for default key bindings. This
    shouldn't include any bits that don't have a fixed meaning. */
-static unsigned long wm_mod = EV_MOD_META;
+static u_long wm_mod = EV_MOD_META;
 
 /* The X modifiers bound to the Num_Lock and Scroll_Lock keysyms */
-static unsigned long num_lock_mod, scroll_lock_mod;
+static u_long num_lock_mod, scroll_lock_mod;
 
 DEFSYM(meta_keysyms, "meta-keysyms");
 DEFSYM(alt_keysyms, "alt-keysyms");
@@ -97,16 +97,17 @@ DEFSYM(super_keysyms, "super-keysyms");
 static void grab_keymap_event (repv km, long code, long mods, bool grab);
 static void grab_all_keylist_events (repv map, bool grab);
 
-static int all_buttons[9] = { Button1, Button2, Button3, Button4, Button5, Button6, Button7, Button8, Button9 };
+static int all_buttons[7] = { Button1, Button2, Button3, Button4, Button5, Button6, Button7 };
 
 /* locks: currently LockMask, num_lock, and scroll_lock */
 static int total_lock_combs, all_lock_mask;
 static int all_lock_combs[2*2*2];
 
+
 /* Translate from X events to Lisp events */
 
-static unsigned long
-direct_modifiers (unsigned long mods)
+static u_long
+direct_modifiers (u_long mods)
 {
     /* Do this first, since it may contain other indirect mods */
     if (wm_mod != 0 && (mods & EV_MOD_WM))
@@ -124,8 +125,8 @@ direct_modifiers (unsigned long mods)
     return mods;
 }
 
-static unsigned long
-indirect_modifiers (unsigned long mods)
+static u_long
+indirect_modifiers (u_long mods)
 {
     if(mods & meta_mod)
 	mods = (mods & ~meta_mod) | EV_MOD_META;
@@ -141,7 +142,7 @@ indirect_modifiers (unsigned long mods)
 
 /* Translate the X key or button event XEV to *CODE and *MODS */
 static bool
-translate_event(unsigned long *code, unsigned long *mods, XEvent *xev)
+translate_event(u_long *code, u_long *mods, XEvent *xev)
 {
     repv multi_click_delay;
     int delay;
@@ -268,12 +269,6 @@ translate_event(unsigned long *code, unsigned long *mods, XEvent *xev)
 	case Button7:
 	    *mods |= Button7Mask;
 	    break;
-	case Button8:
-	    *mods |= Button8Mask;
-	    break;
-	case Button9:
-	    *mods |= Button9Mask;
-	    break;
 	}
 	ret = TRUE;
 	break;
@@ -295,14 +290,14 @@ translate_event(unsigned long *code, unsigned long *mods, XEvent *xev)
 /* Translate the Lisp key event EV to X keycode *KEYCODE and modifier
    mask *STATE, returning true if successful. */
 static bool
-translate_event_to_x_key (repv ev, unsigned int *keycode, unsigned int *state)
+translate_event_to_x_key (repv ev, u_int *keycode, u_int *state)
 {
     if (rep_INT(EVENT_MODS(ev)) & EV_TYPE_KEY)
     {
-	unsigned int s = rep_INT(EVENT_MODS(ev)) & EV_MOD_MASK;
+	u_int s = rep_INT(EVENT_MODS(ev)) & EV_MOD_MASK;
 	KeySym sym = rep_INT(EVENT_CODE(ev));
 	KeySym normal, shifted;
-	unsigned int k = XKeysymToKeycode (dpy, sym);
+	u_int k = XKeysymToKeycode (dpy, sym);
 
 	if (k == 0)
 	    return FALSE;
@@ -333,13 +328,13 @@ translate_event_to_x_key (repv ev, unsigned int *keycode, unsigned int *state)
 
 /* Translate the Lisp button event EV to X button identifier *BUTTON and
    modifier mask *STATE, returning true if successful. */
-static unsigned int
-translate_event_to_x_button (repv ev, unsigned int *button, unsigned int *state)
+static u_int
+translate_event_to_x_button (repv ev, u_int *button, u_int *state)
 {
     if (rep_INT(EVENT_MODS(ev)) & EV_TYPE_MOUSE)
     {
-	unsigned long mods = rep_INT(EVENT_MODS(ev));
-	static struct { unsigned int button; unsigned int mask; } buttons[] = {
+	u_long mods = rep_INT(EVENT_MODS(ev));
+	static struct { u_int button; u_int mask; } buttons[] = {
 	    { Button1, Button1Mask },
 	    { Button2, Button2Mask },
 	    { Button3, Button3Mask },
@@ -347,8 +342,6 @@ translate_event_to_x_button (repv ev, unsigned int *button, unsigned int *state)
 	    { Button5, Button5Mask },
 	    { Button6, Button6Mask },
 	    { Button7, Button7Mask },
-	    { Button8, Button8Mask },
-	    { Button9, Button9Mask },
 	    { 0, 0 }
 	};
 	int i;
@@ -357,7 +350,7 @@ translate_event_to_x_button (repv ev, unsigned int *button, unsigned int *state)
 	{
 	    if (mods & buttons[i].mask)
 	    {
-		unsigned int s;
+		u_int s;
 		mods &= ~buttons[i].mask;
 		s = direct_modifiers (mods & EV_MOD_MASK);
 		if (s == EV_MOD_ANY)
@@ -382,10 +375,11 @@ translate_event_to_x_button (repv ev, unsigned int *button, unsigned int *state)
     return 0;
 }
 
+
 /* Keymap searching */
 
 static inline bool
-compare_events (unsigned long code1, unsigned long mods1, unsigned long code2, unsigned long mods2)
+compare_events (u_long code1, u_long mods1, u_long code2, u_long mods2)
 {
     return (code1 == code2
 	    && ((mods1 == mods2)
@@ -403,7 +397,7 @@ compare_events (unsigned long code1, unsigned long mods1, unsigned long code2, u
    If this function returns true, then this binding is acceptable and
    is returned from the function. */
 static repv
-search_keymap(repv km, unsigned long code, unsigned long mods, bool (*callback)(repv key))
+search_keymap(repv km, u_long code, u_long mods, bool (*callback)(repv key))
 {
     /* If it's a symbol, dereference it. */
     while(rep_SYMBOLP(km) && !rep_NILP(km) && !rep_INTERRUPTP)
@@ -447,7 +441,7 @@ search_keymap(repv km, unsigned long code, unsigned long mods, bool (*callback)(
 
 /* Search for a binding of CODE&MODS.  */
 static repv
-lookup_binding(unsigned long code, unsigned long mods, bool (*callback)(repv key),
+lookup_binding(u_long code, u_long mods, bool (*callback)(repv key),
 	       repv context_keymap, Lisp_Window *current_window)
 {
     repv k = rep_NULL, nkp = next_keymap_path;
@@ -475,7 +469,7 @@ lookup_binding(unsigned long code, unsigned long mods, bool (*callback)(repv key
 	    if (!k && current_window)
 	    {
 		/* 3. search focused/pointer window keymap property */
-	        tem = Fwindow_get (rep_VAL(current_window), Qkeymap, Qnil);
+		tem = Fwindow_get (rep_VAL(current_window), Qkeymap);
 		if (tem && tem != Qnil)
 		    k = search_keymap(tem, code, mods, callback);
 	    }
@@ -535,7 +529,7 @@ eval_input_callback(repv key)
 }
 
 static repv
-lookup_event_binding (unsigned long code, unsigned long mods, repv context_map)
+lookup_event_binding (u_long code, u_long mods, repv context_map)
 {
     Lisp_Window *w = 0;
     if (current_x_event && (mods & EV_TYPE_MOUSE))
@@ -557,7 +551,7 @@ lookup_event_binding (unsigned long code, unsigned long mods, repv context_map)
 repv
 eval_input_event(repv context_map)
 {
-    unsigned long code, mods;
+    u_long code, mods;
     repv result = Qnil, cmd, orig_next_keymap_path = next_keymap_path;
 
     if (!translate_event (&code, &mods, current_x_event))
@@ -640,11 +634,12 @@ eval_input_event(repv context_map)
     return result;
 }
 
+
 /* Translate text->event and vice versa */
 
 struct key_def {
     const char *name;
-    unsigned long mods, code;
+    u_long mods, code;
 };
 
 static struct key_def default_mods[] = {
@@ -672,8 +667,6 @@ static struct key_def default_mods[] = {
     { "Button5",  Button5Mask },
     { "Button6",  Button6Mask },
     { "Button7",  Button7Mask },
-    { "Button8",  Button8Mask },
-    { "Button9",  Button9Mask },
     { "Any",      EV_MOD_ANY },
     { "Release",  EV_MOD_RELEASE },
     { 0, 0 }
@@ -739,7 +732,7 @@ static struct key_def default_codes[] = {
 /* Puts the integers defining the event described in DESC into CODE
    and MODS. */
 static bool
-lookup_event(unsigned long *code, unsigned long *mods, char *desc)
+lookup_event(u_long *code, u_long *mods, u_char *desc)
 {
     char *tem;
     char buf[100];
@@ -750,8 +743,8 @@ lookup_event(unsigned long *code, unsigned long *mods, char *desc)
     {
 	struct key_def *x = default_mods;
 
-	memcpy(buf, desc, tem - desc);
-	buf[tem - desc] = 0;
+	memcpy(buf, desc, tem - (char *)desc);
+	buf[tem - (char *)desc] = 0;
 
 	while(x->name != 0)
 	{
@@ -771,7 +764,7 @@ lookup_event(unsigned long *code, unsigned long *mods, char *desc)
     /* Then go for the code itself */
     {
 	struct key_def *x = default_codes;
-	unsigned int ks;
+	u_int ks;
 	while(x->name != 0)
 	{
 	    if(strcasecmp(desc, x->name) == 0)
@@ -819,21 +812,19 @@ error:
 
 /* Constructs the name of the event defined by CODE and MODS in BUF.  */
 static bool
-lookup_event_name(char *buf, unsigned long code, unsigned long mods)
+lookup_event_name(u_char *buf, u_long code, u_long mods)
 {
     int i;
     struct key_def *x;
-    unsigned long type = mods & EV_TYPE_MASK;
-    char
-        *end = buf,
-        *tem;
+    u_long type = mods & EV_TYPE_MASK;
 
-    *buf = '\0';
+    char *end = buf, *tem;
+    *buf = 0;
 
     mods &= EV_MOD_MASK;
     for(i = 32; i >= 0 && mods != 0; i--)	/* magic numbers!? */
     {
-	unsigned long mask = 1 << i;
+	u_long mask = 1 << i;
 	if(mods & mask)
 	{
 	    mods &= ~mask;
@@ -877,8 +868,8 @@ bool
 print_event_prefix(void)
 {
     int i;
-    char buf[256];
-    char *bufp = buf;
+    u_char buf[256];
+    u_char *bufp = buf;
 
     if (next_keymap_path == rep_NULL)
 	return FALSE;
@@ -910,6 +901,7 @@ print_event_prefix(void)
     return TRUE;
 }
 
+
 /* Lisp functions */
 
 DEFUN("make-keymap", Fmake_keymap, Smake_keymap, (void), rep_Subr0) /*
@@ -941,7 +933,7 @@ Returns KEYMAP when successful.
     args = rep_CDR(args);
     while (rep_CONSP(args) && rep_CONSP(rep_CDR(args)))
     {
-	unsigned long code, mods;
+	u_long code, mods;
 	repv key;
 	arg1 = rep_CAR(args);
 	args = rep_CDR(args);
@@ -989,7 +981,7 @@ unbind-keys KEY-MAP EVENT-DESCRIPTION...
     args = rep_CDR(args);
     while (rep_CONSP(args))
     {
-	unsigned long code, mods;
+	u_long code, mods;
 	repv *keyp;
 	arg1 = rep_CAR(args);
 	if (rep_STRINGP(arg1))
@@ -1064,14 +1056,14 @@ a Lisp function hadn't been called instead.
 ::end:: */
 {
     KeySym ks;
-    char buf[256];
+    u_char buf[256];
     int len;
 
     if(current_x_event == 0)
 	return Fsignal(Qerror, rep_LIST_1(rep_VAL(&not_in_handler)));
 
     len = XLookupString(&current_x_event->xkey,
-                        buf, sizeof (buf) - 1, &ks, NULL);
+			 buf, sizeof (buf) - 1, &ks, NULL);
     if(len > 0)
 	return rep_string_dupn(buf, len);
     else
@@ -1170,7 +1162,7 @@ event-name EVENT
 Returns a string naming the event EVENT.
 ::end:: */
 {
-    char buf[256];
+    u_char buf[256];
     if(!EVENTP(ev))
 	return rep_signal_arg_error(ev, 1);
 
@@ -1190,7 +1182,7 @@ lookup-event EVENT-NAME
 Return the event whose name is EVENT-NAME.
 ::end:: */
 {
-    unsigned long code, mods;
+    u_long code, mods;
     rep_DECLARE1(name, rep_STRINGP);
 
     if(lookup_event(&code, &mods, rep_STR(name)))
@@ -1212,7 +1204,7 @@ currently focused window for keyboard events.
 ::end:: */
 {
     repv res, context = Qnil;
-    unsigned long code, mods;
+    u_long code, mods;
 
     if(!EVENTP(ev))
 	return(rep_signal_arg_error(ev, 1));
@@ -1344,7 +1336,7 @@ again:
 	&& !(wa.all_event_masks & (ButtonPressMask | ButtonReleaseMask)))
     {
 	Window d1, *d2, parent;
-	unsigned int d3;
+	u_int d3;
 	    
 	XQueryTree (dpy, w, &d1, &parent, &d2, &d3);
 	if (d2 != 0)
@@ -1396,7 +1388,7 @@ synthesize-event EVENT WINDOW [PROPAGATE]
 
     switch (rep_INT(EVENT_MODS(event)) & EV_TYPE_MASK)
     {
-	unsigned int mask;
+	u_int mask;
 
     case EV_TYPE_KEY:
 	if (!translate_event_to_x_key (event, &ev.xkey.keycode,
@@ -1453,6 +1445,7 @@ synthesize-event EVENT WINDOW [PROPAGATE]
     return Qt;
 }
 
+
 /* Find the lisp modifier mask used by the meta and alt keys. This code
    shamelessly stolen from Emacs 19. :-) */
 
@@ -1465,17 +1458,6 @@ DEFSTRING(hyper_r, "Hyper_R");
 DEFSTRING(super_l, "Super_L");
 DEFSTRING(super_r, "Super_R");
 
-static void
-nconc (repv x, repv y)
-{
-    repv *ptr = &x;
-
-    while (rep_CONSP (*ptr))
-	ptr = rep_CDRLOC (*ptr);
-
-    *ptr = y;
-}
-
 static void
 find_meta(void)
 {
@@ -1493,10 +1475,6 @@ find_meta(void)
     max_code = dpy->max_keycode;
 #endif
 
-    /* reset to default values. */
-    meta_mod = alt_mod = hyper_mod = super_mod = 0;
-    num_lock_mod = scroll_lock_mod = 0;
-
     Fset (Qmeta_keysyms, Qnil);
     Fset (Qalt_keysyms, Qnil);
     Fset (Qhyper_keysyms, Qnil);
@@ -1578,17 +1556,17 @@ find_meta(void)
 
     if (meta_mod == alt_mod)
     {
-	nconc (meta_syms, alt_syms);
+	meta_syms = Fnconc (rep_list_2 (meta_syms, alt_syms));
 	alt_syms = meta_syms;
     }
     if (meta_mod == hyper_mod)
     {
-	nconc (meta_syms, hyper_syms);
+	meta_syms = Fnconc (rep_list_2 (meta_syms, hyper_syms));
 	hyper_syms = meta_syms;
     }
     if (meta_mod == super_mod)
     {
-	nconc (meta_syms, super_syms);
+	meta_syms = Fnconc (rep_list_2 (meta_syms, super_syms));
 	super_syms = meta_syms;
     }
 
@@ -1603,7 +1581,6 @@ build_lock_mods (void)
 {
     int i;
     total_lock_combs = 2 * (num_lock_mod ? 2 : 1) * (scroll_lock_mod ? 2 : 1);
-    memset (all_lock_combs, 0, sizeof (all_lock_combs));
     for (i = 0; i < total_lock_combs; i++)
     {
 	if (i & 1)
@@ -1624,7 +1601,7 @@ update_keyboard_mapping (void)
 }
 
 static void
-set_wm_modifier (unsigned long mods)
+set_wm_modifier (u_long mods)
 {
     wm_mod = indirect_modifiers (mods);
 }
@@ -1652,6 +1629,7 @@ Returns the current value of the `Window Manager' modifier, an integer.
     return rep_MAKE_INT (wm_mod);
 }
 
+
 /* Key and button grabbing */
 
 static void
@@ -1659,7 +1637,7 @@ grab_event (Window grab_win, repv ev)
 {
     switch (rep_INT(EVENT_MODS(ev)) & EV_TYPE_MASK)
     {
-	unsigned int code, state;
+	u_int code, state;
 	int i;
 
     case EV_TYPE_KEY:
@@ -1703,7 +1681,7 @@ grab_event (Window grab_win, repv ev)
 	    {
 		/* sawmill treats mouse buttons as modifiers, not as
 		   codes, so for us AnyModifier includes all buttons.. */
-		for (i = 0; i < 9; i++)
+		for (i = 0; i < 7; i++)
 		{
 		    XGrabButton (dpy, all_buttons[i], AnyModifier,
 				 grab_win, False, POINTER_GRAB_EVENTS,
@@ -1719,7 +1697,7 @@ ungrab_event (Window grab_win, repv ev)
 {
     switch (rep_INT(EVENT_MODS(ev)) & EV_TYPE_MASK)
     {
-	unsigned int code, state;
+	u_int code, state;
 	int i;
 
     case EV_TYPE_KEY:
@@ -1755,7 +1733,7 @@ ungrab_event (Window grab_win, repv ev)
 	    }
 	    else
 	    {
-		for (i = 0; i < 9; i++)
+		for (i = 0; i < 7; i++)
 		    XUngrabButton (dpy, all_buttons[i], AnyModifier, grab_win);
 	    }
 	}
@@ -1774,7 +1752,7 @@ grab_keymap_event (repv km, long code, long mods, bool grab)
     {
 	if (!WINDOW_IS_GONE_P (w))
 	{
-	    repv tem = Fwindow_get (rep_VAL(w), Qkeymap, Qnil);
+	    repv tem = Fwindow_get (rep_VAL(w), Qkeymap);
 	    if (rep_SYMBOLP(tem) && tem != Qnil)
 		tem = Fsymbol_value (tem, Qt);
 	    if (km == global || tem == km)
@@ -1834,7 +1812,7 @@ grab_window_events (Lisp_Window *w, bool grab)
     tem = Fsymbol_value (Qglobal_keymap, Qt);
     if (tem != Qnil && !rep_VOIDP(tem) && !WINDOW_IS_GONE_P (w))
 	grab_keymap_events (w->id, tem, grab);
-    tem = Fwindow_get (rep_VAL(w), Qkeymap, Qnil);
+    tem = Fwindow_get (rep_VAL(w), Qkeymap);
     if (tem && tem != Qnil && !WINDOW_IS_GONE_P (w))
 	grab_keymap_events (w->id, tem, grab);
 }
@@ -1850,6 +1828,7 @@ keymap_prop_change (Lisp_Window *w, repv prop, repv old, repv new)
     }
 }
 
+
 /* initialisation */
 
 void
