@@ -1,5 +1,5 @@
 /* sawmill_subrs.h -- prototypes
-   $Id: sawmill_subrs.h 4276 2008-08-31 13:15:40Z tkorvola $
+   $Id: sawmill_subrs.h,v 1.99.2.2 2002/05/07 03:17:18 jsh Exp $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -25,8 +25,8 @@
 /* from colors.c */
 extern int color_type;
 extern repv Qdefault_foreground;
-extern repv Fget_color_rgb (repv red, repv green, repv blue, repv alpha);
-extern repv Fget_color (repv name, repv alpha);
+extern repv Fget_color_rgb (repv red, repv green, repv blue);
+extern repv Fget_color (repv name);
 extern repv Fcolor_name (repv color);
 extern repv Fcolor_rgb (repv color);
 extern repv Fcolorp (repv arg);
@@ -51,13 +51,14 @@ extern repv Fcommandp (repv arg);
 extern void commands_init (void);
 
 /* from display.c */
+extern char *prog_name;
 extern Display *dpy;
 extern int screen_num, screen_width, screen_height, preferred_depth;
 extern Visual *preferred_visual;
 extern Window root_window, no_focus_window;
 extern Atom xa_wm_state, xa_wm_change_state, xa_wm_protocols,
     xa_wm_delete_window, xa_wm_colormap_windows, xa_wm_take_focus,
-  xa_compound_text, xa_wm_net_name, xa_wm_net_icon_name, xa_utf8_string;
+    xa_compound_text;
 extern int shape_event_base, shape_error_base;
 extern repv Qdisplay_name, Qcanonical_display_name;
 extern bool sys_init (char *program_name);
@@ -106,9 +107,9 @@ extern void events_kill (void);
 /* from fonts.c */
 extern int font_type;
 extern repv Qdefault_font;
-extern int x_text_width (repv font, char *string, size_t len);
-extern void x_draw_string (Window id, repv font, GC gc, Lisp_Color *fg_color,
-			   int x, int y, char *string, size_t len);
+extern int x_text_width (repv font, u_char *string, size_t len);
+extern void x_draw_string (Window id, repv font, GC gc,
+			   int x, int y, u_char *string, size_t len);
 extern repv Fget_font(repv name);
 extern repv Ffont_get(repv font, repv prop);
 extern repv Ffont_put(repv font, repv prop, repv value);
@@ -174,13 +175,14 @@ extern repv Flist_x_properties (repv win);
 extern repv Fget_x_property (repv win, repv prop);
 extern repv Fset_x_property (repv win, repv prop, repv data,
 			     repv type, repv format);
+extern repv Fget_x_text_property (repv win, repv prop);
+extern repv Fset_x_text_property (repv win, repv prop, repv vect, repv enc);
 extern repv Fsend_client_message (repv win, repv type, repv data, repv format);
 extern repv Fcreate_window (repv parent, repv x, repv y,
 			    repv width, repv height);
 extern repv Fx_atom (repv symbol);
 extern repv Fx_atom_name (repv atom);
 extern repv Fdisplay_message (repv text, repv attrs);
-extern void update_xinerama_info (void);
 extern void functions_init (void);
 extern void functions_kill (void);
 
@@ -189,7 +191,7 @@ extern int image_type;
 extern Colormap image_cmap;
 extern Visual *image_visual;
 extern int image_depth;
-extern Pixmap make_bitmap (repv file, unsigned *widthp, unsigned *heightp,
+extern Pixmap make_bitmap (repv file, int *widthp, int *heightp,
 			   int *x_hotp, int *y_hotp);
 extern repv Fmake_image (repv file, repv plist);
 extern repv Fmake_image_from_x_drawable (repv id, repv mask_id);
@@ -216,7 +218,7 @@ extern void paste_image_to_drawable (Lisp_Image *img, Drawable d,
 				     int x, int y, int w, int h);
 extern int image_width (Lisp_Image *im);
 extern int image_height (Lisp_Image *im);
-extern unsigned char *image_pixels (Lisp_Image *im);
+extern u_char *image_pixels (Lisp_Image *im);
 extern int image_row_stride (Lisp_Image *im);
 extern int image_channels (Lisp_Image *im);
 extern void image_changed (Lisp_Image *im);
@@ -278,12 +280,6 @@ extern void pixmap_cache_flush_image (Lisp_Image *im);
 extern repv Fpixmap_cache_control (repv max);
 extern void pixmap_cache_init (void);
 
-/* from property-cache.c */
-extern repv property_cache_ref (repv id, repv prop);
-extern void property_cache_set (repv id, repv prop, repv value, int invals);
-extern void property_cache_invalidate_window (repv id);
-extern void property_cache_invalidate (repv id, repv prop);
-
 /* from server.c */
 extern void server_init (void);
 extern void server_kill (void);
@@ -316,14 +312,12 @@ extern void after_local_map (Lisp_Window *w);
 extern void install_window_frame (Lisp_Window *w);
 extern void remove_window_frame (Lisp_Window *w);
 extern Lisp_Window *add_window (Window id);
-extern void remove_window (Lisp_Window *win, bool destroyed, bool from_error);
+extern void remove_window (Lisp_Window *win, repv destroyed, repv from_error);
 extern void emit_pending_destroys (void);
-extern repv Fwindow_get (repv win, repv prop, repv checker);
+extern repv Fwindow_get (repv win, repv prop);
 extern void register_property_monitor (repv prop, void (*callback)
 				       (Lisp_Window *, repv, repv, repv));
 extern repv Fwindow_put (repv win, repv prop, repv value);
-extern repv Fwindow_remprop (repv win, repv prop);
-extern repv Fwindow_plist (repv win);
 extern repv Fwindow_name (repv win);
 extern repv Fwindow_full_name (repv win);
 extern repv Fwindow_icon_name (repv win);
@@ -343,6 +337,7 @@ extern repv Fmanaged_windows (void);
 extern repv Fget_window_by_id (repv id);
 extern repv Fstacking_order (void);
 extern repv Fwindow_visibility (repv win);
+extern repv Fwindow_transient_p (repv win);
 extern repv Fwindow_shaped_p (repv win);
 extern repv Fhide_window (repv win);
 extern repv Fshow_window (repv win);
